@@ -3,30 +3,53 @@ from typing import List
 import re
 import matplotlib.pyplot as plt
 from variable_lib_drturtle.variables import *
-
+from dataclasses import dataclass
+from typing import Any
 
 U_RE = re.compile(r"^(?P<name>.+?)(?:\((?P<unit>.+)\))?$", flags=re.MULTILINE)
 
 
+@dataclass
+class Value1D:
+    """Represents one dimension of a two-dimensional value.
+    Should not be created manually, but gotten from a VariableList2D instance.
+    """
+
+    name: str
+    unit: str
+    value: Any
+    values: np.ndarray
+
+    @property
+    def with_unit(self):
+        """Returns the current value of the variable, plus its unit.
+
+        :rtype: str
+        """
+        return f"{self.value} {self.unit}"
+
+    @property
+    def name_val(self):
+        """Returns the name, unit, and current value of the variable.
+
+        :rtype: str
+        """
+        return f"{self.name}: {self.with_unit}"
+
+
 class VariableList2D:
-    def __init__(self, name: str, xi=0, yi=0):
+    def __init__(self, name: str, initial: np.ndarray):
         match = U_RE.match(name)
         self.unit = (match.group("unit") or "").strip()
         self.var_name = match.group("name").strip()
         self.name = f'{self.var_name}{f" ({self.unit})" if self.unit else ""}'.strip()
 
-        initial = np.array([xi, yi])
         self.vals: np.ndarray[np.ndarray] = np.array([initial])
 
     @classmethod
     def from_array(cls, name, arr: np.ndarray):
-        return cls(name, arr[0], arr[1])
-
-    @classmethod
-    def empty(cls, name):
-        inst = cls(name)
-        inst.vals = np.array([])
-        return inst
+        """Depricated"""
+        return cls(name, arr)
 
     def append(self, x, y):
         arr = np.array([x, y])
@@ -95,6 +118,14 @@ class VariableList2D:
     def y_name(self):
         return f"Y {self.name}"
 
+    @property
+    def x(self):
+        return Value1D(f"X {self.name}", self.unit, self.x_values[-1], self.x_values)
+
+    @property
+    def y(self):
+        return Value1D(f"Y {self.name}", self.unit, self.x_values[-1], self.x_values)
+
     @property
     def magnitude(self):
         return np.linalg.norm(self.value)
